# This Build.PL for Mojolicious-Plugin-CascadingConfig was generated by Dist::Zilla::Plugin::ModuleBuildTiny 0.015.
use strict;
use warnings;

use 5.008005;
use Module::Build::Tiny 0.034;
Build_PL();
